--[[

Skillet: A tradeskill window replacement.
Copyright (c) 2007 Robert Clark <nogudnik@gmail.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

]]--

--[[

This file contains functions intended to be used by authors of other mods.
I will make every effort never to change the names or behavior of any of the
methods listed in this file. All bets are off for methods in other files though.

If you would like to see a method added here that would benifit your mod, by all
means contact me and let me know.

]]--

-- Last button added, new buttons will be attached to the left of this
-- start off doing it by name in case the XML file is not loaded yet.
local last_button = "SkilletRescanButton"

local function add_tradejunkie_button()
    if TradeJunkieMain and TJ_OpenButtonTradeSkill then
        if last_button == TJ_OpenButtonTradeSkill then
            -- already attached
            return
        end
    
        -- This button belongs to us now, mwa ha ha ha
        TJ_OpenButtonTradeSkill:ClearAllPoints()
        TJ_OpenButtonTradeSkill:SetParent("SkilletFrame")
        TJ_OpenButtonTradeSkill:SetPoint("TOPRIGHT", last_button, "TOPLEFT", -5, 0)
        TJ_OpenButtonTradeSkill:SetHeight(22)

        -- Override the default action of the button to attach it
        -- to our window, rather than the Blizzard trade skill window
        TJ_OpenButtonTradeSkill:SetScript("OnClick", function()
           TradeJunkie_Attach("SkilletFrame")
           TradeJunkieMain:SetPoint("TOPLEFT", "SkilletFrame", "TOPRIGHT", 0, 0)
        end)

        last_button = TJ_OpenButtonTradeSkill
    end
end

local function add_armorcraft_button()
    if AC_Craft and AC_UseButton and AC_ToggleButton then
        if last_button == AC_UseButton then
            -- already attached
            return
        end
    
        AC_ToggleButton:SetParent("SkilletFrame")
        AC_ToggleButton:SetPoint("TOPRIGHT", last_button, "TOPLEFT", -5, 0)
        AC_ToggleButton:SetAlpha(1.0)

        last_button = AC_ToggleButton
        
        AC_UseButton:SetPoint("RIGHT", last_button, "LEFT");
        AC_UseButton:SetAlpha(1.0)

        last_button = AC_UseButton
        
        AC_Craft:SetParent("SkilletFrame")
        AC_Craft:SetPoint("TOPLEFT","SkilletFrame","TOPRIGHT", 0, 0)
        AC_Craft:SetAlpha(1.0)
        
    end
end

--=================================================================================
--                ******* Start of the public API ********
--=================================================================================

-- Adds a button to the tradeskill window. The button will be
-- reparented and placed appropriately in the window.
--
-- The frame representing the main tradeskill window will be
-- returned in case you need to pop up a frame attached to it.
function Skillet:AddButtonToTradeskillWindow(button)

    if TJ_OpenButtonTradeSkill and button == TJ_OpenButtonTradeSkill then
        add_tradejunkie_button()
    elseif AC_UseButton and button == AC_UseButton then
        add_armorcraft_button()
    else
        if last_button == button then
            -- already attached
            return
        end
    
        -- generic add
        button:ClearAllPoints()
        button:SetParent("SkilletFrame")
        button:SetPoint("TOPRIGHT", last_button, "TOPLEFT", -5, 0)

        last_button = button
    end

    return SkilletFrame
    
end

local function Skillet_NOP()
    -- do nothing!
end

-- A hook to get the reagent label so that mods that mess with it
-- have a place to hook into
function Skillet:GetReagentLabel(skill)
    if (FRC_PriceSource ~= nill and FRC_CraftFrame_SetSelection and FRC_TradeSkillFrame_SetSelection) then
        -- Support for Fizzwidget's Reagent Cost
        if self:IsCraft() then
            local Orig_CraftFrame_SetSelection = FRC_Orig_CraftFrame_SetSelection;
            FRC_Orig_CraftFrame_SetSelection = Skillet_NOP;
            FRC_CraftFrame_SetSelection(skill);
            FRC_Orig_CraftFrame_SetSelection = Orig_CraftFrame_SetSelection;
            return CraftReagentLabel:GetText();
        else
            local Orig_TradeSkillFrame_SetSelection = FRC_Orig_TradeSkillFrame_SetSelection
            FRC_Orig_TradeSkillFrame_SetSelection = Skillet_NOP
            FRC_TradeSkillFrame_SetSelection(skill)
            FRC_Orig_TradeSkillFrame_SetSelection = Orig_TradeSkillFrame_SetSelection
            return TradeSkillReagentLabel:GetText()
        end
    else
        -- boring
        return SPELL_REAGENTS;
    end
end